pub struct EnvironmentVariableDataBlock {
pub block_size: u32,
pub block_signature: u32,
pub target_ansi: Option<Vec<u8>>,
pub target_unicode: Option<Vec<u8>>,
}Expand description
The EnvironmentVariableDataBlock structure specifies a path to environment variable information when the link target refers to a location that has a corresponding environment variable.
Fields
block_size: u32A 32-bit, unsigned integer that specifies the size of the EnvironmentVariableDataBlock structure. This value MUST be 0x00000314.
block_signature: u32A 32-bit, unsigned integer that specifies the signature of the EnvironmentVariableDataBlock extra data section. This value MUST be 0xA0000001.
target_ansi: Option<Vec<u8>>A NULL-terminated string, defined by the system default code page, which specifies a path to environment variable information.
target_unicode: Option<Vec<u8>>An optional, NULL-terminated, Unicode string that specifies a path to environment variable information.