pub struct TrackerDataBlock {
pub block_size: u32,
pub block_signature: u32,
pub length: u32,
pub version: u32,
pub machine_id: u128,
pub droid: [u128; 2],
pub droid_birth: [u128; 2],
}Expand description
The TrackerDataBlock structure specifies data that can be used to resolve a link target if it is not found in its original location when the link is resolved. This data is passed to the Link Tracking service [MS-DLTW] to find the link target.
Fields
block_size: u32A 32-bit, unsigned integer that specifies the size of the TrackerDataBlock structure. This value MUST be 0x00000060.
block_signature: u32A 32-bit, unsigned integer that specifies the signature of the TrackerDataBlock extra data section. This value MUST be 0xA0000003.
length: u32A 32-bit, unsigned integer that specifies the size of the rest of the TrackerDataBlock structure, including this Length field. This value MUST be 0x00000058.
version: u32A 32-bit, unsigned integer. This value MUST be 0x00000000.
machine_id: u128A NULL–terminated character string, as defined by the system default code page, which specifies the NetBIOS name of the machine where the link target was last known to reside.
droid: [u128; 2]Two values in GUID packet representation ([MS-DTYP] section 2.3.4.2) that are used to find the link target with the Link Tracking service, as described in [MS-DLTW].
droid_birth: [u128; 2]Two values in GUID packet representation that are used to find the link target with the Link Tracking service