pub struct SpecialFolderDataBlock {
pub block_size: u32,
pub block_signature: u32,
pub special_folder_id: u32,
pub offset: u32,
}Expand description
The SpecialFolderDataBlock structure specifies the location of a special folder. This data can be used when a link target is a special folder to keep track of the folder, so that the link target IDList can be translated when the link is loaded.
Fields
block_size: u32A 32-bit, unsigned integer that specifies the size of the SpecialFolderDataBlock structure. This value MUST be 0x00000010.
block_signature: u32A 32-bit, unsigned integer that specifies the signature of the SpecialFolderDataBlock extra data section. This value MUST be 0xA0000005.
special_folder_id: u32A 32-bit, unsigned integer that specifies the folder integer ID.
offset: u32A 32-bit, unsigned integer that specifies the location of the ItemID of the first child segment of the IDList specified by SpecialFolderID. This value is the offset, in bytes, into the link target IDList.